from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class XmlSchema:

    @property
    def AttributeFormDefault(self): ...

    @AttributeFormDefault.setter
    def AttributeFormDefault(self): ...

    @property
    def AttributeGroups(self): ...

    @AttributeGroups.setter
    def AttributeGroups(self): ...

    @property
    def Attributes(self): ...

    @Attributes.setter
    def Attributes(self): ...

    @property
    def BlockDefault(self): ...

    @BlockDefault.setter
    def BlockDefault(self): ...

    def Compile(self,
            _: ValidationEventHandler,
            __: System.Xml.XmlResolver,
            ) -> None: ...

    @property
    def ElementFormDefault(self): ...

    @ElementFormDefault.setter
    def ElementFormDefault(self): ...

    @property
    def Elements(self): ...

    @Elements.setter
    def Elements(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def FinalDefault(self): ...

    @FinalDefault.setter
    def FinalDefault(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Groups(self): ...

    @Groups.setter
    def Groups(self): ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def Includes(self): ...

    @Includes.setter
    def Includes(self): ...

    def InstanceNamespace(self, *args, **kwargs) -> Any: ...

    @property
    def IsCompiled(self): ...

    @IsCompiled.setter
    def IsCompiled(self): ...

    @property
    def Items(self): ...

    @Items.setter
    def Items(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    def Namespace(self, *args, **kwargs) -> Any: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    @property
    def Notations(self): ...

    @Notations.setter
    def Notations(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def Read(self,
            _: System.IO.TextReader,
            __: ValidationEventHandler,
            ) -> XmlSchema: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SchemaTypes(self): ...

    @SchemaTypes.setter
    def SchemaTypes(self): ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    @property
    def TargetNamespace(self): ...

    @TargetNamespace.setter
    def TargetNamespace(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    @property
    def Version(self): ...

    @Version.setter
    def Version(self): ...

    def Write(self,
            _: System.IO.TextWriter,
            __: System.Xml.XmlNamespaceManager,
            ) -> None: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_AttributeFormDefault(self) -> XmlSchemaForm: ...

    def get_AttributeGroups(self) -> XmlSchemaObjectTable: ...

    def get_Attributes(self) -> XmlSchemaObjectTable: ...

    def get_BlockDefault(self) -> XmlSchemaDerivationMethod: ...

    def get_ElementFormDefault(self) -> XmlSchemaForm: ...

    def get_Elements(self) -> XmlSchemaObjectTable: ...

    def get_FinalDefault(self) -> XmlSchemaDerivationMethod: ...

    def get_Groups(self) -> XmlSchemaObjectTable: ...

    def get_Id(self) -> str: ...

    def get_Includes(self) -> XmlSchemaObjectCollection: ...

    def get_IsCompiled(self) -> bool: ...

    def get_Items(self) -> XmlSchemaObjectCollection: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Notations(self) -> XmlSchemaObjectTable: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SchemaTypes(self) -> XmlSchemaObjectTable: ...

    def get_SourceUri(self) -> str: ...

    def get_TargetNamespace(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def get_Version(self) -> str: ...

    def set_AttributeFormDefault(self, _: XmlSchemaForm) -> None: ...

    def set_BlockDefault(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_ElementFormDefault(self, _: XmlSchemaForm) -> None: ...

    def set_FinalDefault(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_TargetNamespace(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...

    def set_Version(self, _: str) -> None: ...


class XmlTypeCode:

    def AnyAtomicType(self, *args, **kwargs) -> Any: ...

    def AnyUri(self, *args, **kwargs) -> Any: ...

    def Attribute(self, *args, **kwargs) -> Any: ...

    def Base64Binary(self, *args, **kwargs) -> Any: ...

    def Boolean(self, *args, **kwargs) -> Any: ...

    def Byte(self, *args, **kwargs) -> Any: ...

    def Comment(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Date(self, *args, **kwargs) -> Any: ...

    def DateTime(self, *args, **kwargs) -> Any: ...

    def DayTimeDuration(self, *args, **kwargs) -> Any: ...

    def Decimal(self, *args, **kwargs) -> Any: ...

    def Document(self, *args, **kwargs) -> Any: ...

    def Double(self, *args, **kwargs) -> Any: ...

    def Duration(self, *args, **kwargs) -> Any: ...

    def Element(self, *args, **kwargs) -> Any: ...

    def Entity(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Float(self, *args, **kwargs) -> Any: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GDay(self, *args, **kwargs) -> Any: ...

    def GMonth(self, *args, **kwargs) -> Any: ...

    def GMonthDay(self, *args, **kwargs) -> Any: ...

    def GYear(self, *args, **kwargs) -> Any: ...

    def GYearMonth(self, *args, **kwargs) -> Any: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def HexBinary(self, *args, **kwargs) -> Any: ...

    def Id(self, *args, **kwargs) -> Any: ...

    def Idref(self, *args, **kwargs) -> Any: ...

    def Int(self, *args, **kwargs) -> Any: ...

    def Integer(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def Item(self, *args, **kwargs) -> Any: ...

    def Language(self, *args, **kwargs) -> Any: ...

    def Long(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def NCName(self, *args, **kwargs) -> Any: ...

    def Name(self, *args, **kwargs) -> Any: ...

    def Namespace(self, *args, **kwargs) -> Any: ...

    def NegativeInteger(self, *args, **kwargs) -> Any: ...

    def NmToken(self, *args, **kwargs) -> Any: ...

    def Node(self, *args, **kwargs) -> Any: ...

    def NonNegativeInteger(self, *args, **kwargs) -> Any: ...

    def NonPositiveInteger(self, *args, **kwargs) -> Any: ...

    def NormalizedString(self, *args, **kwargs) -> Any: ...

    def Notation(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def PositiveInteger(self, *args, **kwargs) -> Any: ...

    def ProcessingInstruction(self, *args, **kwargs) -> Any: ...

    def QName(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Short(self, *args, **kwargs) -> Any: ...

    def String(self, *args, **kwargs) -> Any: ...

    def Text(self, *args, **kwargs) -> Any: ...

    def Time(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def Token(self, *args, **kwargs) -> Any: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def UnsignedByte(self, *args, **kwargs) -> Any: ...

    def UnsignedInt(self, *args, **kwargs) -> Any: ...

    def UnsignedLong(self, *args, **kwargs) -> Any: ...

    def UnsignedShort(self, *args, **kwargs) -> Any: ...

    def UntypedAtomic(self, *args, **kwargs) -> Any: ...

    def YearMonthDuration(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaSimpleType:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def BaseSchemaType(self): ...

    @BaseSchemaType.setter
    def BaseSchemaType(self): ...

    @property
    def BaseXmlSchemaType(self): ...

    @BaseXmlSchemaType.setter
    def BaseXmlSchemaType(self): ...

    @property
    def Content(self): ...

    @Content.setter
    def Content(self): ...

    @property
    def Datatype(self): ...

    @Datatype.setter
    def Datatype(self): ...

    @property
    def DerivedBy(self): ...

    @DerivedBy.setter
    def DerivedBy(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Final(self): ...

    @Final.setter
    def Final(self): ...

    @property
    def FinalResolved(self): ...

    @FinalResolved.setter
    def FinalResolved(self): ...

    def Finalize(self) -> None: ...

    def GetBuiltInComplexType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaComplexType: ...

    def GetBuiltInSimpleType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaSimpleType: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    def IsDerivedFrom(self,
            _: XmlSchemaType,
            __: XmlSchemaType,
            ___: XmlSchemaDerivationMethod,
            ) -> bool: ...

    @property
    def IsMixed(self): ...

    @IsMixed.setter
    def IsMixed(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def TypeCode(self): ...

    @TypeCode.setter
    def TypeCode(self): ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_BaseSchemaType(self) -> object: ...

    def get_BaseXmlSchemaType(self) -> XmlSchemaType: ...

    def get_Content(self) -> XmlSchemaSimpleTypeContent: ...

    def get_Datatype(self) -> XmlSchemaDatatype: ...

    def get_DerivedBy(self) -> XmlSchemaDerivationMethod: ...

    def get_Final(self) -> XmlSchemaDerivationMethod: ...

    def get_FinalResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_Id(self) -> str: ...

    def get_IsMixed(self) -> bool: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_TypeCode(self) -> XmlTypeCode: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Content(self, _: XmlSchemaSimpleTypeContent) -> None: ...

    def set_Final(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_IsMixed(self, _: bool) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaSet:

    def Add(self, _: str, __: str) -> XmlSchema: ...

    @property
    def CompilationSettings(self): ...

    @CompilationSettings.setter
    def CompilationSettings(self): ...

    def Compile(self) -> None: ...

    def Contains(self, _: str) -> bool: ...

    def CopyTo(self, _: List[XmlSchema], __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def GlobalAttributes(self): ...

    @GlobalAttributes.setter
    def GlobalAttributes(self): ...

    @property
    def GlobalElements(self): ...

    @GlobalElements.setter
    def GlobalElements(self): ...

    @property
    def GlobalTypes(self): ...

    @GlobalTypes.setter
    def GlobalTypes(self): ...

    @property
    def IsCompiled(self): ...

    @IsCompiled.setter
    def IsCompiled(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def NameTable(self): ...

    @NameTable.setter
    def NameTable(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: XmlSchema) -> XmlSchema: ...

    def RemoveRecursive(self, _: XmlSchema) -> bool: ...

    def Reprocess(self, _: XmlSchema) -> XmlSchema: ...

    def Schemas(self, _: str) -> System.Collections.ICollection: ...

    def ToString(self) -> str: ...

    def ValidationEventHandler(self, *args, **kwargs) -> Any: ...

    @property
    def XmlResolver(self): ...

    @XmlResolver.setter
    def XmlResolver(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_ValidationEventHandler(self,
            _: ValidationEventHandler,
            ) -> None: ...

    def get_CompilationSettings(self) -> XmlSchemaCompilationSettings: ...

    def get_Count(self) -> int: ...

    def get_GlobalAttributes(self) -> XmlSchemaObjectTable: ...

    def get_GlobalElements(self) -> XmlSchemaObjectTable: ...

    def get_GlobalTypes(self) -> XmlSchemaObjectTable: ...

    def get_IsCompiled(self) -> bool: ...

    def get_NameTable(self) -> System.Xml.XmlNameTable: ...

    def remove_ValidationEventHandler(self,
            _: ValidationEventHandler,
            ) -> None: ...

    def set_CompilationSettings(self,
            _: XmlSchemaCompilationSettings,
            ) -> None: ...

    def set_XmlResolver(self, _: System.Xml.XmlResolver) -> None: ...


class XmlSchemaForm:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def Qualified(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Unqualified(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaType:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def BaseSchemaType(self): ...

    @BaseSchemaType.setter
    def BaseSchemaType(self): ...

    @property
    def BaseXmlSchemaType(self): ...

    @BaseXmlSchemaType.setter
    def BaseXmlSchemaType(self): ...

    @property
    def Datatype(self): ...

    @Datatype.setter
    def Datatype(self): ...

    @property
    def DerivedBy(self): ...

    @DerivedBy.setter
    def DerivedBy(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Final(self): ...

    @Final.setter
    def Final(self): ...

    @property
    def FinalResolved(self): ...

    @FinalResolved.setter
    def FinalResolved(self): ...

    def Finalize(self) -> None: ...

    def GetBuiltInComplexType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaComplexType: ...

    def GetBuiltInSimpleType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaSimpleType: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    def IsDerivedFrom(self,
            _: XmlSchemaType,
            __: XmlSchemaType,
            ___: XmlSchemaDerivationMethod,
            ) -> bool: ...

    @property
    def IsMixed(self): ...

    @IsMixed.setter
    def IsMixed(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def TypeCode(self): ...

    @TypeCode.setter
    def TypeCode(self): ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_BaseSchemaType(self) -> object: ...

    def get_BaseXmlSchemaType(self) -> XmlSchemaType: ...

    def get_Datatype(self) -> XmlSchemaDatatype: ...

    def get_DerivedBy(self) -> XmlSchemaDerivationMethod: ...

    def get_Final(self) -> XmlSchemaDerivationMethod: ...

    def get_FinalResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_Id(self) -> str: ...

    def get_IsMixed(self) -> bool: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_TypeCode(self) -> XmlTypeCode: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Final(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_IsMixed(self, _: bool) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaObject:

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...


class XmlSchemaContentModel:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def Content(self): ...

    @Content.setter
    def Content(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Content(self) -> XmlSchemaContent: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Content(self, _: XmlSchemaContent) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaDatatype:

    def ChangeType(self,
            _: object,
            __: Type,
            ___: System.Xml.IXmlNamespaceResolver,
            ) -> object: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IsDerivedFrom(self, _: XmlSchemaDatatype) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ParseValue(self,
            _: str,
            __: System.Xml.XmlNameTable,
            ___: System.Xml.IXmlNamespaceResolver,
            ) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    @property
    def TokenizedType(self): ...

    @TokenizedType.setter
    def TokenizedType(self): ...

    @property
    def TypeCode(self): ...

    @TypeCode.setter
    def TypeCode(self): ...

    @property
    def ValueType(self): ...

    @ValueType.setter
    def ValueType(self): ...

    @property
    def Variety(self): ...

    @Variety.setter
    def Variety(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_TokenizedType(self) -> System.Xml.XmlTokenizedType: ...

    def get_TypeCode(self) -> XmlTypeCode: ...

    def get_ValueType(self) -> Type: ...

    def get_Variety(self) -> XmlSchemaDatatypeVariety: ...


class XmlSchemaObjectTable:

    def Contains(self, _: System.Xml.XmlQualifiedName) -> bool: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IDictionaryEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Names(self): ...

    @Names.setter
    def Names(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    @property
    def Values(self): ...

    @Values.setter
    def Values(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_Item(self,
            _: System.Xml.XmlQualifiedName,
            ) -> XmlSchemaObject: ...

    def get_Names(self) -> System.Collections.ICollection: ...

    def get_Values(self) -> System.Collections.ICollection: ...


class XmlSchemaAnyAttribute:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespace(self): ...

    @Namespace.setter
    def Namespace(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def ProcessContents(self): ...

    @ProcessContents.setter
    def ProcessContents(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespace(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_ProcessContents(self) -> XmlSchemaContentProcessing: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespace(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_ProcessContents(self,
            _: XmlSchemaContentProcessing,
            ) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaComplexType:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def AnyAttribute(self): ...

    @AnyAttribute.setter
    def AnyAttribute(self): ...

    @property
    def AttributeUses(self): ...

    @AttributeUses.setter
    def AttributeUses(self): ...

    @property
    def AttributeWildcard(self): ...

    @AttributeWildcard.setter
    def AttributeWildcard(self): ...

    @property
    def Attributes(self): ...

    @Attributes.setter
    def Attributes(self): ...

    @property
    def BaseSchemaType(self): ...

    @BaseSchemaType.setter
    def BaseSchemaType(self): ...

    @property
    def BaseXmlSchemaType(self): ...

    @BaseXmlSchemaType.setter
    def BaseXmlSchemaType(self): ...

    @property
    def Block(self): ...

    @Block.setter
    def Block(self): ...

    @property
    def BlockResolved(self): ...

    @BlockResolved.setter
    def BlockResolved(self): ...

    @property
    def ContentModel(self): ...

    @ContentModel.setter
    def ContentModel(self): ...

    @property
    def ContentType(self): ...

    @ContentType.setter
    def ContentType(self): ...

    @property
    def ContentTypeParticle(self): ...

    @ContentTypeParticle.setter
    def ContentTypeParticle(self): ...

    @property
    def Datatype(self): ...

    @Datatype.setter
    def Datatype(self): ...

    @property
    def DerivedBy(self): ...

    @DerivedBy.setter
    def DerivedBy(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Final(self): ...

    @Final.setter
    def Final(self): ...

    @property
    def FinalResolved(self): ...

    @FinalResolved.setter
    def FinalResolved(self): ...

    def Finalize(self) -> None: ...

    def GetBuiltInComplexType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaComplexType: ...

    def GetBuiltInSimpleType(self,
            _: XmlTypeCode,
            ) -> XmlSchemaSimpleType: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def IsAbstract(self): ...

    @IsAbstract.setter
    def IsAbstract(self): ...

    def IsDerivedFrom(self,
            _: XmlSchemaType,
            __: XmlSchemaType,
            ___: XmlSchemaDerivationMethod,
            ) -> bool: ...

    @property
    def IsMixed(self): ...

    @IsMixed.setter
    def IsMixed(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def Particle(self): ...

    @Particle.setter
    def Particle(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def TypeCode(self): ...

    @TypeCode.setter
    def TypeCode(self): ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_AnyAttribute(self) -> XmlSchemaAnyAttribute: ...

    def get_AttributeUses(self) -> XmlSchemaObjectTable: ...

    def get_AttributeWildcard(self) -> XmlSchemaAnyAttribute: ...

    def get_Attributes(self) -> XmlSchemaObjectCollection: ...

    def get_BaseSchemaType(self) -> object: ...

    def get_BaseXmlSchemaType(self) -> XmlSchemaType: ...

    def get_Block(self) -> XmlSchemaDerivationMethod: ...

    def get_BlockResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_ContentModel(self) -> XmlSchemaContentModel: ...

    def get_ContentType(self) -> XmlSchemaContentType: ...

    def get_ContentTypeParticle(self) -> XmlSchemaParticle: ...

    def get_Datatype(self) -> XmlSchemaDatatype: ...

    def get_DerivedBy(self) -> XmlSchemaDerivationMethod: ...

    def get_Final(self) -> XmlSchemaDerivationMethod: ...

    def get_FinalResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_Id(self) -> str: ...

    def get_IsAbstract(self) -> bool: ...

    def get_IsMixed(self) -> bool: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_Particle(self) -> XmlSchemaParticle: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_TypeCode(self) -> XmlTypeCode: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_AnyAttribute(self, _: XmlSchemaAnyAttribute) -> None: ...

    def set_Block(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_ContentModel(self, _: XmlSchemaContentModel) -> None: ...

    def set_Final(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_IsAbstract(self, _: bool) -> None: ...

    def set_IsMixed(self, _: bool) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_Particle(self, _: XmlSchemaParticle) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaParticle:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    @property
    def MaxOccurs(self): ...

    @MaxOccurs.setter
    def MaxOccurs(self): ...

    @property
    def MaxOccursString(self): ...

    @MaxOccursString.setter
    def MaxOccursString(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def MinOccurs(self): ...

    @MinOccurs.setter
    def MinOccurs(self): ...

    @property
    def MinOccursString(self): ...

    @MinOccursString.setter
    def MinOccursString(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_MaxOccurs(self) -> float: ...

    def get_MaxOccursString(self) -> str: ...

    def get_MinOccurs(self) -> float: ...

    def get_MinOccursString(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_MaxOccurs(self, _: float) -> None: ...

    def set_MaxOccursString(self, _: str) -> None: ...

    def set_MinOccurs(self, _: float) -> None: ...

    def set_MinOccursString(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaCompilationSettings:

    @property
    def EnableUpaCheck(self): ...

    @EnableUpaCheck.setter
    def EnableUpaCheck(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_EnableUpaCheck(self) -> bool: ...

    def set_EnableUpaCheck(self, _: bool) -> None: ...


class XmlSchemaObjectCollection:

    def Add(self, _: XmlSchemaObject) -> int: ...

    @property
    def Capacity(self): ...

    @Capacity.setter
    def Capacity(self): ...

    def Clear(self) -> None: ...

    def Contains(self, _: XmlSchemaObject) -> bool: ...

    def CopyTo(self, _: List[XmlSchemaObject], __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IndexOf(self, _: XmlSchemaObject) -> int: ...

    @property
    def InnerList(self): ...

    @InnerList.setter
    def InnerList(self): ...

    def Insert(self, _: int, __: XmlSchemaObject) -> None: ...

    @property
    def List(self): ...

    @List.setter
    def List(self): ...

    def MemberwiseClone(self) -> object: ...

    def OnClear(self) -> None: ...

    def OnClearComplete(self) -> None: ...

    def OnInsert(self, _: int, __: object) -> None: ...

    def OnInsertComplete(self, _: int, __: object) -> None: ...

    def OnRemove(self, _: int, __: object) -> None: ...

    def OnRemoveComplete(self, _: int, __: object) -> None: ...

    def OnSet(self, _: int, __: object, ___: object) -> None: ...

    def OnSetComplete(self, _: int, __: object, ___: object) -> None: ...

    def OnValidate(self, _: object) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: XmlSchemaObject) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Capacity(self) -> int: ...

    def get_Count(self) -> int: ...

    def get_InnerList(self) -> List: ...

    def get_Item(self, _: int) -> XmlSchemaObject: ...

    def get_List(self) -> List: ...

    def set_Capacity(self, _: int) -> None: ...

    def set_Item(self, _: int, __: XmlSchemaObject) -> None: ...


class XmlSchemaDerivationMethod:

    def All(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Extension(self, *args, **kwargs) -> Any: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def List(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Restriction(self, *args, **kwargs) -> Any: ...

    def Substitution(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Union(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class ValidationEventHandler:

    def BeginInvoke(self,
            _: object,
            __: ValidationEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self, _: object, __: ValidationEventArgs) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class XmlSchemaAnnotation:

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def Items(self): ...

    @Items.setter
    def Items(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Id(self) -> str: ...

    def get_Items(self) -> XmlSchemaObjectCollection: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class ValidationEventArgs:

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Exception(self): ...

    @Exception.setter
    def Exception(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Message(self): ...

    @Message.setter
    def Message(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def Severity(self): ...

    @Severity.setter
    def Severity(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Exception(self) -> XmlSchemaException: ...

    def get_Message(self) -> str: ...

    def get_Severity(self) -> XmlSeverityType: ...


class XmlSchemaSimpleTypeContent:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaContent:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaContentType:

    def CompareTo(self, _: object) -> int: ...

    def ElementOnly(self, *args, **kwargs) -> Any: ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Mixed(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def TextOnly(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaException:

    @property
    def Data(self): ...

    @Data.setter
    def Data(self): ...

    def GetBaseException(self) -> Exception: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    @property
    def HResult(self): ...

    @HResult.setter
    def HResult(self): ...

    @property
    def HelpLink(self): ...

    @HelpLink.setter
    def HelpLink(self): ...

    @property
    def InnerException(self): ...

    @InnerException.setter
    def InnerException(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    @property
    def Message(self): ...

    @Message.setter
    def Message(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def SerializeObjectState(self, *args, **kwargs) -> Any: ...

    @property
    def Source(self): ...

    @Source.setter
    def Source(self): ...

    @property
    def SourceSchemaObject(self): ...

    @SourceSchemaObject.setter
    def SourceSchemaObject(self): ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    @property
    def StackTrace(self): ...

    @StackTrace.setter
    def StackTrace(self): ...

    @property
    def TargetSite(self): ...

    @TargetSite.setter
    def TargetSite(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_SerializeObjectState(self, _: Any) -> None: ...

    def args(self, *args, **kwargs) -> Any: ...

    def get_Data(self) -> System.Collections.IDictionary: ...

    def get_HResult(self) -> int: ...

    def get_HelpLink(self) -> str: ...

    def get_InnerException(self) -> Exception: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Message(self) -> str: ...

    def get_Source(self) -> str: ...

    def get_SourceSchemaObject(self) -> XmlSchemaObject: ...

    def get_SourceUri(self) -> str: ...

    def get_StackTrace(self) -> str: ...

    def get_TargetSite(self) -> System.Reflection.MethodBase: ...

    def remove_SerializeObjectState(self, _: Any) -> None: ...

    def set_HResult(self, _: int) -> None: ...

    def set_HelpLink(self, _: str) -> None: ...

    def set_Source(self, _: str) -> None: ...

    def with_traceback(self, *args, **kwargs) -> Any: ...


class XmlSeverityType:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Error(self, *args, **kwargs) -> Any: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Warning(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaContentProcessing:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def Lax(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Skip(self, *args, **kwargs) -> Any: ...

    def Strict(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaDatatypeVariety:

    def Atomic(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def List(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Union(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class IXmlSchemaInfo:

    @property
    def IsDefault(self): ...

    @IsDefault.setter
    def IsDefault(self): ...

    @property
    def IsNil(self): ...

    @IsNil.setter
    def IsNil(self): ...

    @property
    def MemberType(self): ...

    @MemberType.setter
    def MemberType(self): ...

    @property
    def SchemaAttribute(self): ...

    @SchemaAttribute.setter
    def SchemaAttribute(self): ...

    @property
    def SchemaElement(self): ...

    @SchemaElement.setter
    def SchemaElement(self): ...

    @property
    def SchemaType(self): ...

    @SchemaType.setter
    def SchemaType(self): ...

    @property
    def Validity(self): ...

    @Validity.setter
    def Validity(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_IsDefault(self) -> bool: ...

    def get_IsNil(self) -> bool: ...

    def get_MemberType(self) -> XmlSchemaSimpleType: ...

    def get_SchemaAttribute(self) -> XmlSchemaAttribute: ...

    def get_SchemaElement(self) -> XmlSchemaElement: ...

    def get_SchemaType(self) -> XmlSchemaType: ...

    def get_Validity(self) -> XmlSchemaValidity: ...


class XmlSchemaValidationFlags:

    def AllowXmlAttributes(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ProcessIdentityConstraints(self, *args, **kwargs) -> Any: ...

    def ProcessInlineSchema(self, *args, **kwargs) -> Any: ...

    def ProcessSchemaLocation(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ReportValidationWarnings(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaValidity:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def Invalid(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def NotKnown(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Valid(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlSchemaElement:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def Block(self): ...

    @Block.setter
    def Block(self): ...

    @property
    def BlockResolved(self): ...

    @BlockResolved.setter
    def BlockResolved(self): ...

    @property
    def Constraints(self): ...

    @Constraints.setter
    def Constraints(self): ...

    @property
    def DefaultValue(self): ...

    @DefaultValue.setter
    def DefaultValue(self): ...

    @property
    def ElementSchemaType(self): ...

    @ElementSchemaType.setter
    def ElementSchemaType(self): ...

    @property
    def ElementType(self): ...

    @ElementType.setter
    def ElementType(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Final(self): ...

    @Final.setter
    def Final(self): ...

    @property
    def FinalResolved(self): ...

    @FinalResolved.setter
    def FinalResolved(self): ...

    def Finalize(self) -> None: ...

    @property
    def FixedValue(self): ...

    @FixedValue.setter
    def FixedValue(self): ...

    @property
    def Form(self): ...

    @Form.setter
    def Form(self): ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def IsAbstract(self): ...

    @IsAbstract.setter
    def IsAbstract(self): ...

    @property
    def IsNillable(self): ...

    @IsNillable.setter
    def IsNillable(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    @property
    def MaxOccurs(self): ...

    @MaxOccurs.setter
    def MaxOccurs(self): ...

    @property
    def MaxOccursString(self): ...

    @MaxOccursString.setter
    def MaxOccursString(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def MinOccurs(self): ...

    @MinOccurs.setter
    def MinOccurs(self): ...

    @property
    def MinOccursString(self): ...

    @MinOccursString.setter
    def MinOccursString(self): ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    @property
    def RefName(self): ...

    @RefName.setter
    def RefName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SchemaType(self): ...

    @SchemaType.setter
    def SchemaType(self): ...

    @property
    def SchemaTypeName(self): ...

    @SchemaTypeName.setter
    def SchemaTypeName(self): ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    @property
    def SubstitutionGroup(self): ...

    @SubstitutionGroup.setter
    def SubstitutionGroup(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_Block(self) -> XmlSchemaDerivationMethod: ...

    def get_BlockResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_Constraints(self) -> XmlSchemaObjectCollection: ...

    def get_DefaultValue(self) -> str: ...

    def get_ElementSchemaType(self) -> XmlSchemaType: ...

    def get_ElementType(self) -> object: ...

    def get_Final(self) -> XmlSchemaDerivationMethod: ...

    def get_FinalResolved(self) -> XmlSchemaDerivationMethod: ...

    def get_FixedValue(self) -> str: ...

    def get_Form(self) -> XmlSchemaForm: ...

    def get_Id(self) -> str: ...

    def get_IsAbstract(self) -> bool: ...

    def get_IsNillable(self) -> bool: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_MaxOccurs(self) -> float: ...

    def get_MaxOccursString(self) -> str: ...

    def get_MinOccurs(self) -> float: ...

    def get_MinOccursString(self) -> str: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_RefName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SchemaType(self) -> XmlSchemaType: ...

    def get_SchemaTypeName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_SubstitutionGroup(self) -> System.Xml.XmlQualifiedName: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_Block(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_DefaultValue(self, _: str) -> None: ...

    def set_Final(self, _: XmlSchemaDerivationMethod) -> None: ...

    def set_FixedValue(self, _: str) -> None: ...

    def set_Form(self, _: XmlSchemaForm) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_IsAbstract(self, _: bool) -> None: ...

    def set_IsNillable(self, _: bool) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_MaxOccurs(self, _: float) -> None: ...

    def set_MaxOccursString(self, _: str) -> None: ...

    def set_MinOccurs(self, _: float) -> None: ...

    def set_MinOccursString(self, _: str) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_RefName(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_SchemaType(self, _: XmlSchemaType) -> None: ...

    def set_SchemaTypeName(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_SubstitutionGroup(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...


class XmlSchemaAttribute:

    @property
    def Annotation(self): ...

    @Annotation.setter
    def Annotation(self): ...

    @property
    def AttributeSchemaType(self): ...

    @AttributeSchemaType.setter
    def AttributeSchemaType(self): ...

    @property
    def AttributeType(self): ...

    @AttributeType.setter
    def AttributeType(self): ...

    @property
    def DefaultValue(self): ...

    @DefaultValue.setter
    def DefaultValue(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    @property
    def FixedValue(self): ...

    @FixedValue.setter
    def FixedValue(self): ...

    @property
    def Form(self): ...

    @Form.setter
    def Form(self): ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def Id(self): ...

    @Id.setter
    def Id(self): ...

    @property
    def LineNumber(self): ...

    @LineNumber.setter
    def LineNumber(self): ...

    @property
    def LinePosition(self): ...

    @LinePosition.setter
    def LinePosition(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    @property
    def Namespaces(self): ...

    @Namespaces.setter
    def Namespaces(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Parent(self): ...

    @Parent.setter
    def Parent(self): ...

    @property
    def QualifiedName(self): ...

    @QualifiedName.setter
    def QualifiedName(self): ...

    @property
    def RefName(self): ...

    @RefName.setter
    def RefName(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SchemaType(self): ...

    @SchemaType.setter
    def SchemaType(self): ...

    @property
    def SchemaTypeName(self): ...

    @SchemaTypeName.setter
    def SchemaTypeName(self): ...

    @property
    def SourceUri(self): ...

    @SourceUri.setter
    def SourceUri(self): ...

    def ToString(self) -> str: ...

    @property
    def UnhandledAttributes(self): ...

    @UnhandledAttributes.setter
    def UnhandledAttributes(self): ...

    @property
    def Use(self): ...

    @Use.setter
    def Use(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Annotation(self) -> XmlSchemaAnnotation: ...

    def get_AttributeSchemaType(self) -> XmlSchemaSimpleType: ...

    def get_AttributeType(self) -> object: ...

    def get_DefaultValue(self) -> str: ...

    def get_FixedValue(self) -> str: ...

    def get_Form(self) -> XmlSchemaForm: ...

    def get_Id(self) -> str: ...

    def get_LineNumber(self) -> int: ...

    def get_LinePosition(self) -> int: ...

    def get_Name(self) -> str: ...

    def get_Namespaces(self) -> System.Xml.Serialization.XmlSerializerNamespaces: ...

    def get_Parent(self) -> XmlSchemaObject: ...

    def get_QualifiedName(self) -> System.Xml.XmlQualifiedName: ...

    def get_RefName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SchemaType(self) -> XmlSchemaSimpleType: ...

    def get_SchemaTypeName(self) -> System.Xml.XmlQualifiedName: ...

    def get_SourceUri(self) -> str: ...

    def get_UnhandledAttributes(self) -> List[System.Xml.XmlAttribute]: ...

    def get_Use(self) -> XmlSchemaUse: ...

    def set_Annotation(self, _: XmlSchemaAnnotation) -> None: ...

    def set_DefaultValue(self, _: str) -> None: ...

    def set_FixedValue(self, _: str) -> None: ...

    def set_Form(self, _: XmlSchemaForm) -> None: ...

    def set_Id(self, _: str) -> None: ...

    def set_LineNumber(self, _: int) -> None: ...

    def set_LinePosition(self, _: int) -> None: ...

    def set_Name(self, _: str) -> None: ...

    def set_Namespaces(self,
            _: System.Xml.Serialization.XmlSerializerNamespaces,
            ) -> None: ...

    def set_Parent(self, _: XmlSchemaObject) -> None: ...

    def set_RefName(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_SchemaType(self, _: XmlSchemaSimpleType) -> None: ...

    def set_SchemaTypeName(self, _: System.Xml.XmlQualifiedName) -> None: ...

    def set_SourceUri(self, _: str) -> None: ...

    def set_UnhandledAttributes(self, _: List[System.Xml.XmlAttribute]) -> None: ...

    def set_Use(self, _: XmlSchemaUse) -> None: ...


class XmlSchemaUse:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Optional(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def Prohibited(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Required(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...
